PTVis
=====

Python package for visualizing data on the periodic table.

Requirements
------------

* Python version 3.9 or later

Installation
------------

You can install PTVis by, e.g., [pip](https://pip.pypa.io/):

``` shell
python -m pip install ptvis
```

Usage
-----

See the [documentation](https://naubuan.gitlab.io/ptvis/).

License
-------

[Apache License, Version 2.0](LICENSE.txt)
